@@ -17,7 +17,7 @@ if 'phonostats' in settings.INSTALLED_APPS:
     from phonostats.utils import getNeighCount,getPhonotacticProb
 
 if 'celex' in settings.INSTALLED_APPS:
-    from celex.utils import lookupStress,lookupCat
+    from celex.utils import lookupFreq,lookupCat
 
 from .utils import fetch_buckeye_resource
 from .managers import BulkManager
@@ -93,6 +93,19 @@ Group by StressVowel) AS averages""",[self.pk])
         self.save()
         return self.AvgSpeakingRate
 
+    def create_dialogs(self):
+        files= os.listdir(fetch_buckeye_resource("Speakers/"+str(s)))
+        dialogs = sorted(set([ f[3:5] for f in files]))
+        Dialog.objects.bulk_create([ Dialog(Speaker=self,Number=d) for d in dialogs])
+
+    def load_dialogs(self):
+        self.create_dialogs()
+        for d in Dialog.objects.filter(Speaker = self):
+            d.load_in()
+
+    def get_path(self):
+        return fetch_buckeye_resource("Speakers/"+unicode(self))
+
 
 
 
@@ -103,6 +116,16 @@ class Dialog(models.Model):
     def __unicode__(self):
         return u'%s%s' % (self.Speaker,self.Number)
 
+    def get_word_files(self):
+        files = os.listdir(self.Speaker.get_path())
+        word_files = [f for f in files if f[:5] == str(d) and re.search("\.words$",f) is not None]
+        return word_files
+
+    def load_in(self):
+        wf = self.get_word_files()
+        for f in wf:
+
+
 class SegmentType(models.Model):
     Label = models.CharField(max_length=10)
     Syllabic = models.BooleanField()
@@ -849,7 +872,7 @@ class WordToken(models.Model):
         if form['frequency'] == 'B':
             outline['frequency'] = self.WordType.getFreq()
         elif form['frequency'] == 'C':
-            outline['frequency'] = lookupFreq(self.WordType.Label,'CELEX')
+            outline['frequency'] = lookupFreq(self.WordType.Label)
         if form['gender']:
             outline['SpeakerGender'] = self.Dialog.Speaker.Gender
         if form['age']:
